@@ -12,5 +12,5 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from nuclio_sdk.test.platform import Platform
+from nuclio_sdk.test.mock_platform import Platform
 from nuclio_sdk.test.test_case import TestCase
